package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.CourseTableTime;

/**
 * 课程-时间Service接口
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
public interface ICourseTableTimeService 
{
    /**
     * 查询课程-时间
     * 
     * @param id 课程-时间主键
     * @return 课程-时间
     */
    public CourseTableTime selectCourseTableTimeById(Long id);

    /**
     * 查询课程-时间列表
     * 
     * @param courseTableTime 课程-时间
     * @return 课程-时间集合
     */
    public List<CourseTableTime> selectCourseTableTimeList(CourseTableTime courseTableTime);

    /**
     * 新增课程-时间
     * 
     * @param courseTableTime 课程-时间
     * @return 结果
     */
    public int insertCourseTableTime(CourseTableTime courseTableTime);

    /**
     * 修改课程-时间
     * 
     * @param courseTableTime 课程-时间
     * @return 结果
     */
    public int updateCourseTableTime(CourseTableTime courseTableTime);

    /**
     * 批量删除课程-时间
     * 
     * @param ids 需要删除的课程-时间主键集合
     * @return 结果
     */
    public int deleteCourseTableTimeByIds(Long[] ids);

    /**
     * 删除课程-时间信息
     * 
     * @param id 课程-时间主键
     * @return 结果
     */
    public int deleteCourseTableTimeById(Long id);
}
